@@ -1,16 +1,17 @@
 """Capture virtual server image."""
 # :license: MIT, see LICENSE for more details.
 
+import click
+
 import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import helpers
 
-import click
+
 # pylint: disable=redefined-builtin
 
-
-@click.command(short_help="Capture SoftLayer image.")
+@click.command(cls=SoftLayer.CLI.command.SLCommand, short_help="Capture SoftLayer image.")
 @click.argument('identifier')
 @click.option('--name', '-n', required=True, help="Name of the image")
 @click.option('--all', help="Capture all disks belonging to the VS")
@@ -24,9 +25,9 @@ def cli(env, identifier, name, all, note):
 
     capture = vsi.capture(vs_id, name, all, note)
 
-    table = formatting.KeyValueTable(['Name', 'Value'])
-    table.align['Name'] = 'r'
-    table.align['Value'] = 'l'
+    table = formatting.KeyValueTable(['name', 'value'])
+    table.align['name'] = 'r'
+    table.align['value'] = 'l'
 
     table.add_row(['vs_id', capture['guestId']])
     table.add_row(['date', capture['createDate'][:10]])
