@@ -360,13 +360,14 @@ class NetworkTests(testing.TestCase):
         self.assertEqual(result, fixtures.SoftLayer_Account.getNetworkVlans)
         _filter = {
             'networkVlans': {
-                'primaryRouter': {
-                    'datacenter': {
-                        'name': {'operation': '_= dal00'}},
-                },
+                'id': {
+                    'operation': 'orderBy',
+                    'options': [
+                        {'name': 'sort', 'value': ['ASC']}]},
                 'vlanNumber': {'operation': 5},
                 'name': {'operation': '_= primary-vlan'},
-            },
+                'primaryRouter': {
+                    'datacenter': {'name': {'operation': '_= dal00'}}}}
         }
         self.assert_called_with('SoftLayer_Account', 'getNetworkVlans',
                                 filter=_filter)
@@ -628,3 +629,33 @@ class NetworkTests(testing.TestCase):
     def test_get_all_pods(self):
         self.network.get_pods()
         self.assert_called_with('SoftLayer_Network_Pod', 'getAllObjects')
+
+    def test_route(self):
+        self.network.route('SoftLayer_Hardware_Server', 123456, 100)
+        self.assert_called_with('SoftLayer_Network_Subnet', 'route')
+
+    def test_get_all_datacenter(self):
+        self.network.get_datacenter()
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters')
+        self.network.get_datacenter(datacenter="dal11")
+        expected_filter = {"name": {"operation": "dal11"}}
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters', filter=expected_filter)
+
+    def test_get_datacenter_by_keyname(self):
+        # normal operation
+        result = self.network.get_datacenter_by_keyname("TEST01")
+        expected_filter = {"regions": {"keyname": {"operation": "TEST01"}}}
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters', filter=expected_filter)
+        self.assertEqual(result.get('name'), 'dal13')
+
+        # an "empty" result
+        SoftLayer_Location = self.set_mock('SoftLayer_Location', 'getDatacenters')
+        SoftLayer_Location.return_value = []
+        result = self.network.get_datacenter_by_keyname("TEST01")
+        self.assertEqual(result, {})
+
+    def test_clear_route(self):
+        result = self.network.clear_route(1234)
+
+        self.assertEqual(result, True)
+        self.assert_called_with('SoftLayer_Network_Subnet', 'clearRoute')
